..


.. Keep the current version number on line number 5
0.0.2
=====

* Remove CSS classes on 'ul' tags

* Remove CSS classes on 'a' tags


0.0.1
=====

* Remove unnecessary output


0.0.0
=====


.. EOF
